@@ -3,7 +3,7 @@
 ### icewm-menu-Desktop.sh - dynamic menu of ~/Desktop files & recursive folders to open via dynamic menu
 ###           set to use antiX execute in terminal command: desktop-defaults-run -t
 
-### BobC 09/04/19
+### BobC 12/27/20 fixes for locales and empty list
 
 ### --- example output ---
 ###prog "alsamixer" gnome-volume-control x-terminal-emulator -e alsamixer
@@ -18,8 +18,12 @@
 ###}
 ###prog "spacefm-root" spacefm-root gksu spacefm 
 
-walk_dir () {
-	for pathname in "$1"/*; do
+walk_dir() {
+    if [[ -z $(ls -A "$1") ]]; then
+        # Empty dir
+        return
+    fi
+    for pathname in "$1"/*; do
         basename=$( echo ${pathname##*/} | sed 's/\"//g' )
         dispname=$( echo ${basename} | sed 's/%20/ /g' )
         localfile=$( echo ${pathname} | sed 's/file:\/\///g' | sed 's/\"//g' |sed 's/%20/ /g' )
@@ -75,7 +79,7 @@ walk_dir () {
     done
 }
 
-TOP_DIR=~/Desktop
+TOP_DIR="$XDG_DESKTOP_DIR"
 export TERMCMD='desktop-defaults-run -t'
 export curdirlevel=1
 walk_dir "$TOP_DIR"
